#
# spec file for package tuxpaint
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         gnomedir   %(gnome-config --prefix)
Name:           tuxpaint
Version:        0.9.23
Release:        bp153.1.18
Summary:        Drawing Program for Young Children
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Bitmap Editors
URL:            http://www.tuxpaint.org/
Source:         http://sourceforge.net/projects/tuxpaint/files/tuxpaint/%{version}/%{name}-%{version}.tar.gz
Source1:        tuxpaint-rpmlintrc
# PATCH-FIX-OPENSUSE 0001-Prepare-the-kdelibs4-removal.patch
Patch0:         kdelibs4-removal.patch
Patch1:         tuxpaint-import-eval.patch
BuildRequires:  SDL-devel
BuildRequires:  SDL_Pango-devel
BuildRequires:  SDL_image-devel
BuildRequires:  SDL_mixer-devel
BuildRequires:  SDL_ttf-devel > 2.0.8
BuildRequires:  fribidi-devel
BuildRequires:  gperf
BuildRequires:  libpaper-devel
BuildRequires:  libpng-devel
BuildRequires:  zlib-devel
#
# openSUSE
#
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  librsvg-devel
BuildRequires:  update-desktop-files
Requires:       freefont
Requires:       netpbm
Recommends:     tuxpaint-config
Recommends:     tuxpaint-stamps
%endif
#
# Fedora
#
%if 0%{?fedora_version}
BuildRequires:  desktop-file-utils
BuildRequires:  freetype-devel >= 2.0
BuildRequires:  gettext
BuildRequires:  librsvg2-devel
BuildRequires:  netpbm-devel
# This should guarantee the proper permissions on
# all of the /usr/share/icons/hicolor/* directories.
Requires:       hicolor-icon-theme
%endif

%description
Tux Paint" is a drawing program for young children. It has a simple
interface and fixed canvas size, and provides access to previous images
using a thumbnail browser (it provides no access to the underlying
filesystem).

Unlike popular drawing programs such as "The GIMP," it has a very
limited toolset. However, it provides a much simpler interface, and has
entertaining, child-oriented additions such as sound effects.

%package devel
Summary:        Devel files of tuxpaint
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       SDL-devel
Requires:       SDL_Pango-devel
Requires:       SDL_image-devel
Requires:       SDL_mixer-devel
Requires:       SDL_ttf-devel
Requires:       fribidi-devel
Requires:       libpaper-devel
Requires:       libpng-devel
Requires:       zlib-devel
%if 0%{?suse_version}
Requires:       gcc-c++
Requires:       gettext-devel
Requires:       librsvg-devel
%endif
%if 0%{?fedora_version}
Requires:       gettext
Requires:       librsvg2-devel
%endif

%description devel
Header files and development documentation for tuxpaint.

%prep
%setup -q
%patch0 -p1
%patch1  -b .import-eval-patch
find . -name CVS   -print0 | xargs -0 rm -rf
find docs/ -type f -print0 | xargs -0 chmod -v 644

make PREFIX=%{_prefix} MAGIC_PREFIX=%{_libdir}/%{name}/plugins tp-magic-config

%build
make %{?_smp_mflags} \
     PREFIX=%{_prefix} \
     CFLAGS="%{optflags}" \
     MAGIC_PREFIX=%{_libdir}/%{name}/plugins -lpng14

%install
%if ! 0%{?suse_version}
mkdir -p %{buildroot}
%endif
make install install-kde-icons \
             PREFIX="%{_prefix}" \
             X11_ICON_PREFIX="%{buildroot}/%{_datadir}/pixmaps" \
             MAGIC_PREFIX="%{buildroot}/%{_libdir}/%{name}/plugins" \
             GNOME_PREFIX="%{_prefix}" \
             KDE_ICON_PREFIX="%{_datadir}/icons" \
%if 0%{?suse_version}
             DEVDOC_PREFIX="%{buildroot}/%{_defaultdocdir}/%{name}-devel" \
             DOC_PREFIX="%{buildroot}/%{_defaultdocdir}/%{name}" \
%endif
             DESTDIR=%{buildroot}

find %{buildroot}/%{_mandir} -type f -exec chmod 644 {} \;
find %{buildroot} -type d -exec chmod 0755 {} \;

%if 0%{?suse_version}
find %{buildroot} -name "*.desktop" -exec rm -v {} \;
%suse_update_desktop_file -i %{name} Game KidsGame
%fdupes -s %{buildroot}
%else
desktop-file-install --dir %{buildroot}/%{_datadir}/applications \
    --vendor %{vendor} \
    --add-category KidsGame \
    --delete-original \
    %{buildroot}/%{_datadir}/applications/tuxpaint.desktop
rm -rf %{buildroot}/%{_docdir}/%{name}
%endif
# remove unneeded scripts
rm %{buildroot}/%{_datadir}/%{name}/fonts/locale/zh_tw_docs/*.{sh,py,pe}
# find lang
%find_lang %{name}

%files -f %{name}.lang
%if 0%{?suse_version}
%doc %{_defaultdocdir}/%{name}
%endif
%{_mandir}/man1/tuxpaint*
%{_mandir}/pl/man1/tuxpaint.1%{?ext_man}
%dir %{_sysconfdir}/%{name}
%dir %{_mandir}/pl
%dir %{_mandir}/pl/man1
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/bash_completion.d/tuxpaint-completion.bash
%{_bindir}/%{name}
%{_bindir}/tuxpaint-import
%{_libdir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/pixmaps/%{name}.*
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor
%if 0%{?suse_version} <= 1130
# locales not in official openSUSE distribution
%dir %{_datadir}/locale/en_ZA
%dir %{_datadir}/locale/en_ZA/LC_MESSAGES
%dir %{_datadir}/locale/gos
%dir %{_datadir}/locale/gos/LC_MESSAGES
%dir %{_datadir}/locale/nr
%dir %{_datadir}/locale/nr/LC_MESSAGES
%dir %{_datadir}/locale/oj
%dir %{_datadir}/locale/oj/LC_MESSAGES
%dir %{_datadir}/locale/tlh
%dir %{_datadir}/locale/tlh/LC_MESSAGES
%if ! %{defined fedora}
%dir %{_datadir}/locale/twi
%dir %{_datadir}/locale/twi/LC_MESSAGES
%endif
%dir %{_datadir}/locale/shs
%dir %{_datadir}/locale/shs/LC_MESSAGES
%dir %{_datadir}/locale/son
%dir %{_datadir}/locale/son/LC_MESSAGES
%dir %{_datadir}/locale/zam
%dir %{_datadir}/locale/zam/LC_MESSAGES
%endif

%files devel
%if 0%{?suse_version}
%doc %{_defaultdocdir}/%{name}-devel
%endif
%{_mandir}/man1/tp-magic-config*
%dir %{_includedir}/%{name}
%{_bindir}/tp-magic-config
%{_includedir}/%{name}/*

%changelog
* Thu Oct  3 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unneeded libgnome-devel BuildRequires: tuxpaint builds fine
  without it.
* Tue Apr 16 2019 lars@linux-schulserver.de - 0.9.23
- update to 0.9.23:
  * New tools: * Color selector
  * New shapes: * Stars
  * Documentation updates: * Made stamp controls (size, flip, mirror)
    section clearer.
    Fixes https://sourceforge.net/p/tuxpaint/bugs/182/
  * Cleaned up and reorganized docs subdirectory.
  * New locales: Bengali, Bodo, Dogri, Kabyle (aka Kabylian),
    Kashmiri (Devanagari), Sindhi (Devanagari), Urdu
  * Localization Updates
  * Bug Fixes:
    + Crash if any "mosaic" magic tool used, Xubuntu 15.10
    If the PNG patterns used to generate the effect were compressed
    the wrong(lossy) way, the program will crash
    (SF.net Bug #210)
    + "Hat" started could not be drawn on.  Mended.
    https://sourceforge.net/p/tuxpaint/bugs/202/
  * Other Improvements:
    + Reformatted source code via GNU Indent tool; should
    greatly increase code readability and formatting consistency.
- removed reproducible.patch: fixed upstream
- adjusted 0001-Prepare-the-kdelibs4-removal.patch (kdelibs4-removal.patch)
* Tue Mar 26 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix the previous commit. The build service picked the wrong
  revision.
* Mon Mar 25 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Prepare-the-kdelibs4-removal.patch to prepare the
  kdelibs4 removal
- Run spec-cleaner
* Sat Jul 14 2018 bwiedemann@suse.com
- Add reproducible.patch to override build date (boo#1047218)
* Mon Apr 13 2015 badshah400@gmail.com
- Add tuxpaint-rpmlintrc file as a source in specfile.
* Tue Apr  7 2015 p.drouand@gmail.com
- Use download Url as source
- Update project Url
* Sat Dec 27 2014 lars@linux-schulserver.de
- update to 0.9.22:
  + 14 new magic tools
  + 40 new template pictures
  + nearly 200 new stamps
  + support for SVG and KidPix templates
  + and an enhanced text tool
  + also features accessibility improvements, including keyboard and
    joystick pointer controls, and an on-screen keyboard
  Please read /usr/share/doc/packages/tuxpaint/CHANGES.txt
  for more details
- removed upstreamed patches:
  + tuxpaint-manpage_fix.patch
  + tuxpaint-linux_arch_links.patch
  + tuxpaint-de_translation.patch
  + tuxpaint-libpng15.patch
- ran spec-cleaner
* Tue May 14 2013 lars@linux-schulserver.de
- as recommended by rpmlint: switch RPM group of the devel package
  to Development/Libraries/C and C++
* Thu Aug 30 2012 pgajdos@suse.com
- fixed build with libpng15
  * libpng15.patch
* Mon Jul  9 2012 cfarrell@suse.com
- license update: GPL-2.0+
  SPDX format
* Fri Jun 29 2012 lars@linux-schulserver.de
- added tuxpaint-manpage_fix.patch to fix typos in manpage
- dropped tuxpaint-link.patch for tuxpaint-linux_arch_links.patch
  which uses a more flexible way finding libpng
* Mon Nov 21 2011 cyberorg@opensuse.org
- add tuxpaint-link.patch to fix build on 12.1
* Sun Jul  3 2011 lars@linux-schulserver.de
- fix build on newer openSUSE distributions (unknown language dirs
  are removed automatically now)
* Fri Dec 25 2009 lars@linux-schulserver.de
- specfile cleanup
- build with MAGIC_PREFIX="%%buildroot/%%_libdir/%%name/plugins" to
  have the plugins in lib64 on 64bit machines
* Mon Aug  3 2009 lars@linux-schulserver.de
- fix german translation (tuxpaint-de_translation.patch)
* Mon Aug  3 2009 lars@linux-schulserver.de
- update to 0.9.21:
  + two dozen new Magic tools
  + a brush that paints with 'toothpaste', and others that paint
    with confetti, rain, snowballs, and snowflakes
  + Starter Images are now easier to make
  + Text tool now supports bidirectional languages
  + Two new languages: Shuswap and Songhay
  + many other translations have been updated
  + On Linux, environment variables (like "$HOME") may now be used
    when setting directories for saving images or finding
    data files
  + and a number of minor improvements and bug fixes requested by
    the Tux Paint community
  + For a complete list of changes, see the Tux Paint ChangeLog
- added fribidi-devel to BuildRequires
- install KDE icons, too
- strip the binaries
- enable fedory build
* Tue Mar 17 2009 lars@linux-schulserver.de
- fix build on older distributions
* Wed Oct  1 2008 lrupp@suse.de
- update to 0.9.20:
  + Many localisation updates
  + Build System improvements
  + Documentation improvements
  + Bugfixes
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Tue Mar  4 2008 lars@linux-schulserver.de
- update to 0.9.19:
  + New Localizations:
  - Australian English
  - Azerbaijani
  - Canadian English
  - Khmer
  - Macedonian
  - Occitan
  - Zapoteco
  + Localization Updates:
  - British English translation
  - Chinese (Simplified) README and FAQ documentation
  - Danish translation
  - Esperanto translation
  - Faroese translation
  - Finnish translation
  - French translation
  - Gujarati translation
  - Russian translation
  + System-Related Improvements:
  - Added "--allowscreensaver" option, which prevents Tux Paint
    from disabling the screensaver or monitor power management
    while running.
  - Removed unfinished, unused record and playback code.
  + Documentation Improvements:
  - Brought documentation on Tux Paint canvas size
    up-to-date, for importing photos/etc.
  + Recreated "Tux Paint" title art using Inkscape
    (traced original bitmap).
  + Larger "Tux Paint" title art displayed on larger screens.
  + Corrected bug where Shift and Kaleidoscope magic tools would crash
    when sound was disabled.
  + Corrected issues that prevented building Tux Paint without sound
    support (extraneous SDL_mixer library calls).
  + Preventing crash when starter images could not be loaded
    (when trying to flip or mirror them).
* Mon Feb 11 2008 lars@linux-schulserver.de
- update to 0.9.19-cvs-2007.12.11:
  + Localization Updates: da, fi, fr, gu, ru,
  + Removed unfinished, unused record and playback code
  + Brought documentation on Tux Paint canvas size up-to-date
  + Corrected bug where Shift and Kaleidoscope magic tools would
    crash when sound was disabled
  + Preventing crash when starter images could not be loaded
  + .. (see CHANGES file)
* Tue Jan  1 2008 lars@linux-schulserver.de
- split out devel file for tp-magic-config (plugin development)
- rework specfile, part 1
* Fri Nov 23 2007 lars@linux-schulserver.de
- updates:
  + tuxpaint-0.9.18
  + tuxpaint-stamps-2007.11.21
  + tuxpaint-config-0.0.9.tar.gz
- important changes (for more see ChangeLog):
  + Speed up prompt animations, and made them 'fly' from their
    sources
  + Center image of directional brushes shown. (SF.net #1658697)
  + Added a 'color picker' entry to the color palette
  + Any current text being written in the Text tool is applied
    to the picture if 'Print' is clicked. (Useful if kids are told
    to add their name to a picture when they're done, right before
    printing, but they forget to hit [Enter].)
  + All stamps can be forced to start at a particular size
  + Added an API for developing Magic tools as plug-ins.
  + Began adding support for using SDL_Pango
  + Lockfile can be disabled via options file ("nolockfile=yes")
    now, too.
* Mon Aug 13 2007 lrupp@suse.de
- use fdupes
* Tue Aug  7 2007 sndirsch@suse.de
- updated to release 0.9.17:
  * Scalable Vector Graphic (SVG) stamps, Japanese and Korean text
    entry, improved printing and monitor support, and stamp
    categories are just a few of the many improvements.
* Mon Jul  9 2007 sndirsch@suse.de
- fixed BuildRequires for openSUSE > 10.2
* Tue Jan  9 2007 sndirsch@suse.de
- fixed %%files section for openSUSE > 10.2
* Mon Nov  6 2006 sndirsch@suse.de
- fixed file permissions
* Mon Oct 23 2006 sndirsch@suse.de
- updated to release 0.9.16
  * interface improvements
  * tool improvements
  * new brushes
  * new starter images
  * new translations
  * translation updates
  * documentation improvements
  * compiling, porting and packaging updates
  * bug fixes
* Wed Sep 13 2006 ro@suse.de
- added -lpng to linkspec for tuxpaint (SDL does not do that anymore)
* Sat Aug 19 2006 sndirsch@suse.de
- moved SuSEconfig.tuxpaint to /usr/share/doc/packages/tuxpaint
* Tue Aug  8 2006 sndirsch@suse.de
- adjusted to new freefont font path
* Sun Jul 23 2006 sndirsch@suse.de
- fixed build for X.Org 7
* Mon Jan 30 2006 ro@suse.de
- added gcc-c++ to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Nov 27 2005 sndirsch@suse.de
- updated to release 0.9.15b
- added tuxpaint-config
* Thu Sep  8 2005 sndirsch@suse.de
- fixed file permissions (#114849)
* Thu Sep  1 2005 sndirsch@suse.de
- added desktop icon (Bug #113666)
* Fri Aug 26 2005 sndirsch@suse.de
- SuSEconfig.tuxpaint:
  * only check for fonts when "--force" is specified (Bug #113259)
* Thu Jul 28 2005 sndirsch@suse.de
- added libmikmod to #neededforbuild
* Mon Jul 25 2005 sndirsch@suse.de
- fixed build with new SDL
* Fri Jul 22 2005 sndirsch@suse.de
- added SDL_mixer-devel to #neededforbuild
* Fri Mar 18 2005 sndirsch@suse.de
- added netpbm to Requires; needed for printing
* Fri Dec  3 2004 sndirsch@suse.de
- replaced kochi font with mikachan font
* Sat Oct 30 2004 sndirsch@suse.de
- added japanese font as sazanami font doesn't work
* Sat Oct 30 2004 sndirsch@suse.de
- package tuxpaint locale fonts (el,he,hi,ta,vi); use them as
  fallback if no other fonts match
* Fri Oct 29 2004 sndirsch@suse.de
- improved SuSEconfig.tuxpaint
* Tue Oct 26 2004 sndirsch@suse.de
- update to release 0.9.14
* Sun Oct 17 2004 ro@suse.de
- removed ttf-kochi-gothic from neededforbuild (dropped)
* Mon Aug 16 2004 sndirsch@suse.de
- improved SuSEconfig.tuxpaint
* Thu Aug  5 2004 sndirsch@suse.de
- create symlinks to greek and CJK fonts on-the-fly via
  SuSEconfig.tuxpaint
* Thu Mar 18 2004 sndirsch@suse.de
- use FreeSerif for greek font support now; require freefont
  package instead of double packaging these fonts (Bug #36385)
* Mon Feb 23 2004 sndirsch@suse.de
- changed desktop category to KidsGame
* Tue Feb 17 2004 sndirsch@suse.de
- fixed desktop category: X-SuSE-School --> X-SuSE-Teaching
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Sat Dec 27 2003 sndirsch@suse.de
- updated to release 0.9.13
- updated Rubber Stams to release 2003.12.23
* Sat Aug 23 2003 sndirsch@suse.de
- updated to release 0.9.12
* Mon Aug 11 2003 sndirsch@suse.de
- added desktop file
* Wed Jul  9 2003 sndirsch@suse.de
- fixed for de_DE.UTF-8 and other UTF-8 locales
* Wed Jun 18 2003 sndirsch@suse.de
- updated to release 0.9.11
- added font support for CJK and greek
* Fri Jun 13 2003 sndirsch@suse.de
- fixed filelist
* Tue May 27 2003 coolo@suse.de
- use BuildRoot
- fix %%_docdir permissions
* Wed Feb  5 2003 sndirsch@suse.de
- updated to release 0.9.9
- updated Rubber Stams to release 2003.01.28
* Thu Jan 30 2003 sndirsch@suse.de
- updated to release 0.9.6
* Sat Jan 18 2003 sndirsch@suse.de
- updated to release 0.9.5
- added Rubber Stamps
* Sun Dec 29 2002 sndirsch@suse.de
- updated to release 0.9.2
* Sat Oct 26 2002 sndirsch@suse.de
- created package
